package envoy.client.ui.list;

import javax.swing.BoxLayout;
import javax.swing.JPanel;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>ComponentList.java</strong><br>
 * Created: <strong>25.01.2020</strong><br>
 * 
 * @author Kai S. K. Engelbart
 * @since Envoy v0.3-alpha
 */
public class ComponentList<E> extends JPanel {

	private ComponentListModel<E>			model;
	private ComponentListCellRenderer<E> renderer;

	private static final long serialVersionUID = 1759644503942876737L;

	public ComponentList(ComponentListModel<E> model, ComponentListCellRenderer<E> renderer) {
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
		this.model		= model;
		this.renderer	= renderer;
		setModel(model);
	}

	public void setModel(ComponentListModel<E> model) {
		// Remove old model
		this.model.clear();
		this.model.setComponentList(null);

		// Synchronize with new model
		this.model = model;
		this.model.setComponentList(this);
		synchronizeModel();
	}

	void add(E elem) {
		add(renderer.getListCellComponent(this, elem, false));
	}

	private void synchronizeModel() {
		removeAll();
		for (E elem : model)
			add(renderer.getListCellComponent(this, elem, false));
	}
}
